/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.rational.clearcase.nt_i386'
packageversion '[8.0.0,8.1.0)'

query_order {	
	custom {
		install {
			commonlicensing
			processstopping
			bypassalbdcheck
			serviceaccountdomain
			serviceaccountuser
			serviceaccountpassword
			serviceaccountgroup
			registryserver
			windowsregion
			unixregion
			mailserver
			remoteadmin
			mvfscasesensitive
			mvfscasepreserving
			mvfsdriveletter
			mvfsscalingfactor
			mvfsvobmnodes
			mvfscleartextmnodes
			ccfs
			customizeccexplorerpopupmenu
			ccexplorerpopupmenufile
			customizeccexplorertoolshortcuts
			ccexplorertoolshortcutsfile
			desktopshortcut
			useatrialicensing
			atrialicensingtype
			atrialicensinghost
			atrialicensingkey
		}
		uninstall {
			serviceaccountuser
			serviceaccountpassword
		}
	}
}

//def S_IPv4_REGEX = "^(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\.(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\." + "(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\.(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])$"
//def S_IPv6_REGEX = "(^(:{2}((([0-9A-Fa-f]{1,4})?)|(([0-9A-Fa-f]{1,4}:){1,5}[0-9A-Fa-f]{1,4})))$)|" + "(^(([0-9A-Fa-f]{1,4}:){7}[0-9A-Fa-f]{1,4})$|^(([0-9A-Fa-f]{1,4}:){5}:((([0-9A-Fa-f]{1,4}:)[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){4}:((([0-9A-Fa-f]{1,4}:){1,2}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){3}:((([0-9A-Fa-f]{1,4}:){1,3}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){2}:((([0-9A-Fa-f]{1,4}:){1,4}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:):((([0-9A-Fa-f]{1,4}:){1,5}[0-9A-Fa-f]{1,4})|(([0-9A-Fa-f]{1,4})?)))$)"
//def S_HOST_NAME_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]*))$"
//def S_DNS_HOST_NAME_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]{0,61}[a-zA-Z0-9])?\\.)+[a-zA-Z0-9]{2,61}$"
//def S_LOCAL_DOMAIN_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]{0,61}[a-zA-Z0-9])?\\.)+localdomain"


query {
	id "commonlicensing"
	required false
	dependencies advancedType
	label "Enter the TCP/IP port and host name of one or more license servers"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
    	com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.RCL_PortAtHost", commonlicensing)
	}
}

query {
	id "processstopping"
	required true
	dependencies advancedType
	label "Stop running processes associated with the product"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
    inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (processstopping.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.StopRunningProcesses", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.StopRunningProcesses", "false")
		}
	}
}

query {
	id "bypassalbdcheck"
	required false
	dependencies features
	label "Bypass ALBD account check"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (bypassalbdcheck.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_DisableAccountConfiguration", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_DisableAccountConfiguration", "false")
		}
	}
}

query {
	id "serviceaccountdomain"
	required true
	dependencies features
	label "Service Account domain"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_AccountDomain", serviceaccountdomain)
	}
}

query {
	id "serviceaccountuser"
	required true
	dependencies features
	label "Service Account user name"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		(serviceaccountuser.size() < 20) && (serviceaccountuser.lastIndexOf('.') < (serviceaccountuser.size() - 1)) && (serviceaccountuser.indexOf(',') == -1 && serviceaccountuser.indexOf('"') == -1 && serviceaccountuser.indexOf('/') == -1 && serviceaccountuser.indexOf('\\') == -1 && serviceaccountuser.indexOf('[') == -1 && serviceaccountuser.indexOf(']') == -1 && serviceaccountuser.indexOf(':') == -1 && serviceaccountuser.indexOf('|') == -1 && serviceaccountuser.indexOf('<') == -1 && serviceaccountuser.indexOf('>') == -1 && serviceaccountuser.indexOf('+') == -1 && serviceaccountuser.indexOf('=') == -1 && serviceaccountuser.indexOf(';') == -1 && serviceaccountuser.indexOf('?') == -1 && serviceaccountuser.indexOf('*') == -1)
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_ServerProcessUserID", serviceaccountuser)
	}
}

query {
	id "serviceaccountpassword"
	required true
	dependencies features
	label "Service Account password"
	labelType "text"
	inputType "password"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		serviceaccountpassword = com.ibm.edp.rfe.model.ModelUtil.encryptValue( serviceaccountpassword )
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_ServerProcessPassword", serviceaccountpassword)
	}
}

query {
	id "serviceaccountgroup"
	required true
	dependencies features
	label "ClearCase Administrator group"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		(serviceaccountgroup.size() < 256) && (!serviceaccountgroup.equalsIgnoreCase(serviceaccountuser))
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_AdminGroup", serviceaccountgroup)
	}
}

query {
	id "registryserver"
	required true
	dependencies features
	label "Registry server host name"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		registryserver.size() < 256
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegSvrHostName", registryserver)
	}
}

query {
	id "windowsregion"
	required true
	dependencies features
	label "Windows registry region"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegWinRegionName", windowsregion)
	}
}

query {
	id "unixregion"
	required false
	dependencies features
	label "UNIX registry region"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegUNIXRegionName", unixregion)
	}
}

query {
	id "mailserver"
	required false
	dependencies features
	label "SMTP mail server host name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegSMTPHostName", mailserver)
	}
}

query {
	id "remoteadmin"
	required false
	dependencies features
	label "Do you want to disable remote administration for ClearCase"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (remoteadmin == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RemoteAdministrationAccess", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RemoteAdministrationAccess", "0")
		}
	}
}

query {
	id "mvfscasesensitive"
	required false
	dependencies features
	label "Do you want to use Windows-style file lookup that is not case-sensitive"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (mvfscasesensitive == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSCaseInsensitivity", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSCaseInsensitivity", "0")
		}
	}
}

query {
	id "mvfscasepreserving"
	required false
	dependencies features
	label "Do you want to use preserve the case of view-private filenames"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes") && mvfscasesensitive == "Yes"
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (mvfscasepreserving == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSCasePreserved", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSCasePreserved", "0")
		}
		if (mvfscasesensitive == "Yes" && mvfscasepreserving == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.MVFSCIFlag", "3")
		}
		else if (mvfscasesensitive == "No" && mvfscasepreserving == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.MVFSCIFlag", "2")
		}
		else if (mvfscasesensitive == "Yes" && mvfscasepreserving == "No") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.MVFSCIFlag", "1")
		}
		else if (mvfscasesensitive == "No" && mvfscasepreserving == "No") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.MVFSCIFlag", "0")
		}
	}
}

query {
	id "mvfsdriveletter"
	required false
	dependencies features
	label "Drive letter used to mount dynamic views"
	labelType "text"
	inputType "list"
	inputDefault "M:"
	inputOptions "M:,N:,O:,P:,Q:,R:,S:,T:,U:,V:,W:,X:,Y:,Z:"
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_DynamicViewsDriveLetter", mvfsdriveletter)
	}
}

query {
	id "mvfsscalingfactor"
	required true
	dependencies features
	label "Scaling factor for initializing MVFS cache size"
	labelType "text"
	inputType "list"
	inputDefault "1"
	inputOptions "0,1,2,3,4,5"
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_ScalingFactor", mvfsscalingfactor)
	}
}

query {
	id "mvfsvobmnodes"
	required true
	dependencies features
	label "Maximum number of mnodes to keep on the VOB free list"
	labelType "text"
	inputType "text"
	inputDefault {
		if (mvfsscalingfactor == "0") {
			"0"
		}
		else {
			def scalingfactor = Integer.parseInt(mvfsscalingfactor, 10)
			def vobmnodes = (scalingfactor + 1) * 900
			Integer.toString( vobmnodes, 10)
		}
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MaxNumMnodesKeepOnVOBFreeList", mvfsvobmnodes)
	}
}

query {
	id "mvfscleartextmnodes"
	required true
	dependencies features
	label "Maximum number of mnodes to keep on the cleartext free list"
	labelType "text"
	inputType "text"
	inputDefault {
		if (mvfsscalingfactor == "0") {
			"0"
		}
		else {
			"1800"
		}
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MaxNumMnodesKeepOnCleartextFreeList", mvfscleartextmnodes)
	}
}

query {
	id "ccfs"
	required false
	dependencies features
	label "Enable ClearCase File Server"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (ccfs == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_EnableCCFS", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_EnableCCFS", "0")
		}
	}
}

query {
	id "customizeccexplorerpopupmenu"
	required false
	dependencies features
	label "Do you want to specify a pop-up menu customization file for ClearCase Explorer"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (customizeccexplorerpopupmenu == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerContextMenuCustomMenu", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerContextMenuCustomMenu", "false")
		}
	}
}

query {
	id "ccexplorerpopupmenufile"
	required false
	dependencies features
	label "Pop-up menu customization file location for ClearCase Explorer"
	labelType "text"
	inputType "text"
	condition {
		customizeccexplorerpopupmenu == "Yes"
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerContextMenuLocation", ccexplorerpopupmenufile)
	}
}

query {
	id "customizeccexplorertoolshortcuts"
	required false
	dependencies features
	label "Do you want to specify a tool shortcuts customization file for ClearCase Explorer"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (customizeccexplorertoolshortcuts.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerToolShortcutsUseShortcut", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerToolShortcutsUseShortcut", "false")
		}
	}
}

query {
	id "ccexplorertoolshortcutsfile"
	required false
	dependencies features
	label "Tool shortcuts customization file location for ClearCase Explorer"
	labelType "text"
	inputType "text"
	condition {
		customizeccexplorertoolshortcuts == "Yes"
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerToolShortcutsLocation", ccexplorertoolshortcutsfile)
	}
}

query {
	id "desktopshortcut"
	required false
	dependencies features
	label "Create a shortcut for ClearCase Explorer on the desktop"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (desktopshortcut == "Yes") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerCreateShortcut", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_CCExplorerCreateShortcut", "false")
		}
	}
}

query {
	id "useatrialicensing"
	required false
	dependencies features
	label "Use ClearCase Atria licensing"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "No,Yes"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (useatrialicensing == "No") {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_LICENSE_MANAGER", "IBMRCL")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_LICENSE_MANAGER", "ATRIA")
		}
	}
}

query {
	id "atrialicensingtype"
	required false
	dependencies features
	label "Where is your license server"
	labelType "text"
	inputType "list"
	inputDefault "Remote"
	inputOptions "Remote,Local"
    inputIgnoreCase true
	condition {
		useatrialicensing.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (atrialicensingtype.equalsIgnoreCase("Remote")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "true")
		} else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "false")
		}
	}
}

query {
	id "atrialicensinghost"
	required false
	dependencies features
	label "Remote license server host name"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Remote")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_REMOTE_HOSTNAME", atrialicensinghost)
	}
}

query {
	id "atrialicensingkey"
	required false
	dependencies features
	label "Local license keys"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Local")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_LOCAL_KEY", atrialicensingkey)
	}
}